@@ -2,8 +2,9 @@
 as a replacement for the standard traceback in IDLE."""
 
 import inspect
-from pathlib import Path
 import sys
+from pathlib import Path
+from functools import partial
 
 
 from idlelib import run as idlelib_run
@@ -19,7 +20,7 @@ from friendly_traceback.functions_help import add_help_attribute
 from friendly import get_lang
 from friendly import settings
 from ..my_gettext import current_lang
-from . import idle_formatter
+from .. import idle_writer
 from . import patch_source_cache  # noqa
 from .get_syntax import get_syntax_error
 
@@ -28,6 +29,7 @@ settings.ENVIRONMENT = "IDLE"
 set_lang(get_lang())
 
 friendly_traceback.exclude_file_from_traceback(__file__)
+_writer = partial(idle_writer.writer, stream=sys.stdout.shell)
 
 
 def history():
@@ -38,24 +40,12 @@ def history():
     for info in session.saved_info:
         message = session.formatter(info, include="message")
         if message:
-            idle_writer(message[1:])
-
-
-# TODO: look at removing this as an option
-def set_formatter(formatter="idle"):
-    """Sets the formatter; the default value is 'idle'."""
-    if formatter == "idle":
-        friendly_traceback.set_formatter(idle_formatter.idle_formatter)
-    else:
-        friendly_traceback.set_formatter(formatter=formatter)
+            _writer(message[1:])
 
 
 set_lang.__doc__ = Friendly.set_lang.__doc__
 
-add_help_attribute(
-    {"history": history, "set_formatter": set_formatter, "set_lang": set_lang}
-)
-Friendly.add_helper(set_formatter)
+add_help_attribute({"history": history, "set_lang": set_lang})
 Friendly.add_helper(set_lang)
 Friendly.add_helper(history)
 _old_displayhook = sys.displayhook
@@ -64,13 +54,14 @@ helpers["get_syntax_error"] = get_syntax_error
 
 Friendly.remove_helper("disable")
 Friendly.remove_helper("enable")
+Friendly.remove_helper("set_formatter")
 
 
 def _displayhook(value):
     if value is None:
         return
     if str(type(value)) == "<class 'function'>" and hasattr(value, "__rich_repr__"):
-        idle_writer(
+        _writer(
             [
                 (f"    {value.__name__}():", "default"),
                 (f" {value.__rich_repr__()[0]}", "stdout"),
@@ -90,38 +81,17 @@ def _displayhook(value):
                     else:
                         newline.append((content, "default"))
                 newline.append("\n")
-                idle_writer(newline)
+                _writer(newline)
             elif "():" in line:
                 parts = line.split("():")
-                idle_writer(
-                    ((f"{    parts[0]}():", "default"), (parts[1], "stdout"), "\n")
-                )
+                _writer(((f"{    parts[0]}():", "default"), (parts[1], "stdout"), "\n"))
             else:
-                idle_writer(line + "\n")
+                _writer(line + "\n")
         return
 
     _old_displayhook(value)
 
 
-def idle_writer(output, color=None):
-    """Use this instead of standard sys.stderr to write traceback so that
-    they can be colorized.
-    """
-    if isinstance(output, str):
-        if color is None:
-            sys.stdout.shell.write(output, "stderr")  # noqa
-        else:
-            sys.stdout.shell.write(output, color)  # noqa
-        return
-    for fragment in output:
-        if isinstance(fragment, str):
-            sys.stdout.shell.write(fragment, "stderr")  # noqa
-        elif len(fragment) == 2:
-            sys.stdout.shell.write(fragment[0], fragment[1])  # noqa
-        else:
-            sys.stdout.shell.write(fragment[0], "stderr")  # noqa
-
-
 def install_in_idle_shell(lang=get_lang()):
     """Installs Friendly in IDLE's shell so that it can retrieve
     code entered in IDLE's repl.
@@ -132,7 +102,7 @@ def install_in_idle_shell(lang=get_lang()):
     raises SyntaxErrors.
     """
     friendly_traceback.exclude_file_from_traceback(idlelib_run.__file__)
-    friendly_traceback.install(include="friendly_tb", redirect=idle_writer, lang=lang)
+    friendly_traceback.install(include="friendly_tb", redirect=_writer, lang=lang)
 
 
 def install(lang=get_lang()):
@@ -140,27 +110,30 @@ def install(lang=get_lang()):
     For Python versions before 3.10, this was not directly supported, so a
     Friendly console is used instead of IDLE's shell.
 
-    Changes introduced in Python 3.10 were back-ported to Python 3.9.5.
+    Changes introduced in Python 3.10 were back-ported to Python 3.9.5 and
+    to Python 3.8.10.
     """
     _ = current_lang.translate
 
     sys.stderr = sys.stdout.shell  # noqa
-    friendly_traceback.set_formatter(idle_formatter.idle_formatter)
-    if sys.version_info >= (3, 9, 5):
+    friendly_traceback.set_formatter(idle_writer.formatter)
+    if sys.version_info >= (3, 9, 5) or (
+        sys.version_info >= (3, 8, 10) and sys.version_info < (3, 9, 0)
+    ):
         install_in_idle_shell(lang=lang)
         sys.displayhook = _displayhook
     else:
-        idle_writer(_("Friendly cannot be installed in this version of IDLE.\n"))
-        idle_writer(_("Using Friendly's own console instead.\n"))
+        _writer(_("Friendly cannot be installed in this version of IDLE.\n"))
+        _writer(_("Using Friendly's own console instead.\n"))
         start_console(lang=lang, displayhook=_displayhook)
 
 
 def start_console(lang="en", displayhook=None, ipython_prompt=True):
     """Starts a Friendly console with a custom formatter for IDLE"""
     sys.stderr = sys.stdout.shell  # noqa
-    friendly_traceback.set_stream(idle_writer)
+    friendly_traceback.set_stream(_writer)
     friendly_traceback.start_console(
-        formatter=idle_formatter.idle_formatter,
+        formatter=idle_writer.formatter,
         lang=lang,
         displayhook=displayhook,
         ipython_prompt=ipython_prompt,
@@ -208,8 +181,8 @@ def run(
     _ = current_lang.translate
 
     sys.stderr = sys.stdout.shell  # noqa
-    friendly_traceback.set_formatter(idle_formatter.idle_formatter)
-    friendly_traceback.set_stream(idle_writer)
+    friendly_traceback.set_formatter(idle_writer.formatter)
+    friendly_traceback.set_stream(_writer)
 
     filename = Path(filename)
     if not filename.is_absolute():
@@ -224,7 +197,9 @@ def run(
         return
 
     if not console:
-        if sys.version_info >= (3, 10):
+        if sys.version_info >= (3, 9, 5) or (
+            sys.version_info >= (3, 8, 10) and sys.version_info < (3, 9, 0)
+        ):
             install_in_idle_shell()
         else:
             sys.stderr.write("Friendly cannot be installed in this version of IDLE.\n")
@@ -235,6 +210,6 @@ def run(
         include=include,
         args=args,
         console=console,
-        formatter=idle_formatter.idle_formatter,
+        formatter=idle_writer.formatter,
         ipython_prompt=ipython_prompt,
     )
